@@ -1,25 +1,23 @@
-# -*- coding: utf-8 -*-
 import matplotlib
 
-
 matplotlib.use("Agg")
 import matplotlib.pyplot as plt
+import pandas as pd
 import pytest
+from toolbox_utils import tsutils
 
 from tstoolbox import tstoolbox
 
+# Pull this in once.
+idf = tsutils.common_kwds(input_tsd="tests/02234500_65_65.csv", clean=True)
 
-# Pull this in once.
-df = tstoolbox.aggregate(
-    agg_interval="D", clean=True, input_ts="tests/02234500_65_65.csv"
-)
-# Pull this in once.
-dfa = tstoolbox.aggregate(
-    agg_interval="A", clean=True, input_ts="tests/02234500_65_65.csv"
-)
-dfa = tstoolbox.equation(
-    "x1*120@x2", input_ts=dfa, output_names=["Elevation::mean", "Flow::mean"]
-)
+df = idf.resample("D").agg("mean")
+
+ndfa = idf.resample("A").agg("mean")
+
+dfa = pd.DataFrame()
+dfa["Elevation::mean"] = ndfa.iloc[:, 0] * 120
+dfa["Flow::mean"] = ndfa.iloc[:, 1]
 
 
 @pytest.mark.mpl_image_compare(tolerance=6)
@@ -63,16 +61,16 @@ def test_double_mass_marker():
 @pytest.mark.mpl_image_compare(tolerance=6)
 def test_boxplot():
     plt.close("all")
-    xdf = tstoolbox.read(
-        ["tests/02234500_65_65.csv", "tests/02325000_flow.csv"],
-        clean=True,
-        append="combine",
+    xdf = pd.read_csv("tests/02234500_65_65.csv", index_col=0, parse_dates=True)
+    xdf = xdf.join(
+        pd.read_csv("tests/data_02325000_flow.csv", index_col=0, parse_dates=True),
+        how="outer",
     )
     return tstoolbox.plot(
+        type="boxplot",
         input_ts=xdf,
         clean=True,
         columns=[2, 3],
-        type="boxplot",
         ofilename=None,
         plot_styles="classic",
     )
@@ -81,8 +79,7 @@ def test_boxplot():
 # @pytest.mark.mpl_image_compare(tolerance=6)
 # def test_scatter_matrix():
 #     plt.close("all")
-#     return tstoolbox.plot(
-#         type="scatter_matrix",
+#     return tstoolbox.scatter_matrix(
 #         clean=True,
 #         input_ts="tests/02234500_65_65.csv",
 #         ofilename=None,
@@ -94,7 +91,7 @@ def test_boxplot():
 def test_lag_plot():
     plt.close("all")
     return tstoolbox.plot(
-        columns=1, type="lag_plot", input_ts=df, ofilename=None, plot_styles="classic"
+        type="lag_plot", columns=1, input_ts=df, ofilename=None, plot_styles="classic"
     )
 
 
